/******************************************************************************
* File Name:   main.c
*
* Description: This is the source code for the Empty PSoC4  Application
*              for ModusToolbox.
*
* Related Document: See README.md
*
*
*******************************************************************************
* Copyright 2020-2021, Cypress Semiconductor Corporation (an Infineon company) or
* an affiliate of Cypress Semiconductor Corporation.  All rights reserved.
*
* This software, including source code, documentation and related
* materials ("Software") is owned by Cypress Semiconductor Corporation
* or one of its affiliates ("Cypress") and is protected by and subject to
* worldwide patent protection (United States and foreign),
* United States copyright laws and international treaty provisions.
* Therefore, you may use this Software only as provided in the license
* agreement accompanying the software package from which you
* obtained this Software ("EULA").
* If no EULA applies, Cypress hereby grants you a personal, non-exclusive,
* non-transferable license to copy, modify, and compile the Software
* source code solely for use in connection with Cypress's
* integrated circuit products.  Any reproduction, modification, translation,
* compilation, or representation of this Software except as specified
* above is prohibited without the express written permission of Cypress.
*
* Disclaimer: THIS SOFTWARE IS PROVIDED AS-IS, WITH NO WARRANTY OF ANY KIND,
* EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT, IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. Cypress
* reserves the right to make changes to the Software without notice. Cypress
* does not assume any liability arising out of the application or use of the
* Software or any product or circuit described in the Software. Cypress does
* not authorize its products for use in any products where a malfunction or
* failure of the Cypress product may reasonably be expected to result in
* significant property damage, injury or death ("High Risk Product"). By
* including Cypress's product in a High Risk Product, the manufacturer
* of such system or application assumes all risk of such use and in doing
* so agrees to indemnify Cypress against all liability.
*******************************************************************************/

#include "cy_pdl.h"
#include "cybsp.h"
#include "cyhal.h"
#include "cy_retarget_io.h"
#include "wave.h"
#define DEBOUNCE_DELAY_MS   1000u
cyhal_i2s_t i2s;
cy_rslt_t     rslt;
cyhal_clock_t clock_pll;
cyhal_clock_t clock_hf;
cyhal_clock_t clock_sys;

cyhal_clock_t audio_clock;
cyhal_clock_t pll_clock;

const cyhal_i2s_pins_t i2s_tx_pins = {
    .sck  = P8_1,
    .ws   = P8_2,
    .data = P8_3,
	.mclk = NC
};

cyhal_i2s_config_t config  =
    {
        .is_tx_slave    = false,
        .is_rx_slave    = false,
        .mclk_hz        = 0,
        .channel_length = 32,//32,
        .word_length    = 32, //
        .sample_rate_hz = 1000//
    };

#define BUFFER_SIZE 128u
 uint32_t  tx_buffer0[BUFFER_SIZE];
 uint32_t  tx_buffer1[BUFFER_SIZE];
const uint32_t* active_tx_buffer;
const uint32_t* next_tx_buffer;


void clock_init(void)
{

	cyhal_clock_allocate( &audio_clock, CYHAL_CLOCK_BLOCK_PERIPHERAL_16_5BIT );
    cyhal_clock_set_frequency( &audio_clock, 8192000, NULL );
    cyhal_clock_set_enabled( &audio_clock, true, true );
}


static void i2s_event_handler_transmit_streaming(void* arg, cyhal_i2s_event_t event)
{

    cyhal_i2s_t* i2s = (cyhal_i2s_t*)arg;
    if (0u != (event & CYHAL_I2S_ASYNC_TX_COMPLETE))
    {
	    printf("TR2\r\n");
        cyhal_i2s_stop_tx(i2s);
    }

}

int main(void)
{
    cy_rslt_t result;

    /* Initialize the device and board peripherals */
    result = cybsp_init() ;
    if (result != CY_RSLT_SUCCESS)
    {
        CY_ASSERT(0);
    }
    /* Initialize retarget-io to use the debug UART port */
	cy_rslt_t rslt = cy_retarget_io_init(CYBSP_DEBUG_UART_TX, CYBSP_DEBUG_UART_RX,
                                 CY_RETARGET_IO_BAUDRATE);
    /* Enable global interrupts */
    __enable_irq();

    printf("clock_init\r\n");
    clock_init();

    /* Initialize the User Button */
    cyhal_gpio_init(CYBSP_USER_BTN, CYHAL_GPIO_DIR_INPUT, CYHAL_GPIO_DRIVE_PULLUP, CYBSP_BTN_OFF);
    /* Enable the button interrupt to wake-up the CPU */
    cyhal_gpio_enable_event(CYBSP_USER_BTN, CYHAL_GPIO_IRQ_FALL, CYHAL_ISR_PRIORITY_DEFAULT, true);

   // result = cyhal_i2s_init(&i2s, &i2s_tx_pins, NULL, &config, &audio_clock );
     result = cyhal_i2s_init(&i2s, &i2s_tx_pins, NULL, &config, NULL);
    if (CY_RSLT_SUCCESS != result)
    {
    	printf("handle error\r\n");
         // Handle error
    	while(1);
    }


    // Register callback function
    cyhal_i2s_register_callback(&i2s, &i2s_event_handler_transmit_streaming, &i2s);
    // Enable the Asynchronous transfer event
    cyhal_i2s_enable_event(&i2s, CYHAL_I2S_ASYNC_TX_COMPLETE, CYHAL_ISR_PRIORITY_DEFAULT, true);


    // Configure asynchronous transfers to use DMA to free up the CPU during transfers
    result = cyhal_i2s_set_async_mode(&i2s, CYHAL_ASYNC_DMA, CYHAL_DMA_PRIORITY_HIGH);

    printf("modesuccess\r\n");


    for (;;)
    {

        if (cyhal_gpio_read(CYBSP_USER_BTN) == CYBSP_BTN_PRESSED)
        {
            /* Check if I2S is transmitting */
            if (cyhal_i2s_is_write_pending(&i2s))
            {
                /* If already transmitting, don't do anything */
            }
            else
            {
                 printf("Trigger\r\n");


        	     cyhal_i2s_clear_tx(&i2s);
                 //result = cyhal_i2s_write_async(&i2s, tx_buffer0, BUFFER_SIZE);
                 result = cyhal_i2s_write_async(&i2s, wave_data, WAVE_SIZE);
                 if (CY_RSLT_SUCCESS != result) {
                 	printf("cyhal_i2s_write_async error\r\n");
                 }
                /* Start the I2S TX */

                result = cyhal_i2s_start_tx(&i2s);
                if (CY_RSLT_SUCCESS != result) {
                	printf("cyhal_i2s_start_tx error\r\n");
                }

            }

            /* Debounce delay */
            cyhal_system_delay_ms(DEBOUNCE_DELAY_MS);
        }

    }
}

/* [] END OF FILE */
